@@ -3,7 +3,9 @@ import mimetypes
 import re
 
 from django.core.urlresolvers import reverse
-from django.contrib.staticfiles.templatetags.staticfiles import static
+from django.conf import settings
+
+from fileupload import constants
 
 
 def order_name(name):
@@ -27,19 +29,22 @@ def serialize(instance, file_attr='file'):
 
     """
     obj = getattr(instance, file_attr)
-    mimetype = mimetypes.guess_type(obj.path)[0] or 'image/png'
+    mimetype = mimetypes.guess_type(obj.name)[0] or 'image/png'
     if re.match(r'image', mimetype):
         # We can only really display the thumbnail, if it is an image
-        thumbnailUrl = obj.url
+        thumbnail_url = obj.url
     else:
         # Otherwise we will display a default placeholder image
-        thumbnailUrl = static('img/default-thumbnail.png')
+        if hasattr(settings, 'UPLOADER_DEFAULT_THUMBNAIL'):
+            thumbnail_url = settings.UPLOADER_DEFAULT_THUMBNAIL
+        else:
+            thumbnail_url = constants.UPLOADER_DEFAULT_THUMBNAIL
 
     return {
         'url': obj.url,
         'name': order_name(obj.name),
         'type': mimetype,
-        'thumbnailUrl': thumbnailUrl,
+        'thumbnailUrl': thumbnail_url,
         'size': obj.size,
         'deleteUrl': reverse('upload-delete', args=[instance.pk]),
         'deleteType': 'DELETE',
